Ver despois | CRTVG
Description: CRTVG - Compañía de Radio/Televisión de Galicia
Keywords: TVG, CRTVG, Radio Galega, television, radio, galicia, galiza, galega, agalega, acarta, video, audio, radio galega musica, son galicia radio, television de galicia, galicia television, carteleira, tempo, licitacion, deporte, visita do Papa, Bieito XVI, Benedicto XVI, 25 anos,

Usuario
Contrasinal
Recordar
Esqueceu o contrasinal?
Rexístrate

# CRTVG

xoves 11 de decembro

- Ingresa I
- Rexístrate

Buscador

Para utilizar o servizo Ver despois debes estar rexistrado

Usuario
Contrasinal
Recordar
Esqueceu o contrasinal?
Rexístrate
Agora podes gardar contidos da tvg para ver despois
Cando non teñas tempo de ver un episodio que che guste, podes picar no botón "ver despois". Se estás rexistrado en crtvg.es, o episodio gardarase na túa lista de "ver despois"
No teu espazo "ver despois" terás todos os episodios gardados. Poderás marcarlos como favoritos ou eliminalos se xa os viches.
"Ver despois" é multiplataforma: todo o que gardes na web poderás consultalo nas aplicacións móbiles da CRTVG, nas súas versións Android, iPhone e iPad.
Consíguelo en el AppStore Google Play